#!/usr/bin/ruby

require 'fileutils'
require 'rbconfig'
include FileUtils

rc_d = 'rc.d'
if not File.exist? rc_d then
  rc_d = "../lib/smalltalkx/6.2.5/lib/rc.d"
end

token="bug_86_starting_stx_with_saved_image_kills_the_whole_environment"


stx_cmd = nil
if File.exist? 'stx.com' then
  stx_cmd = 'stx.com'
elsif File.exist? 'stx-bin.com' then
  stx_cmd = 'stx-bin.com'
else
  stx_cmd = './stx'
end
puts "stx_cmd = #{stx_cmd.inspect}"

File.open("#{rc_d}/99-#{token}.rc", "w") do | f |
  f.write <<END
(OperatingSystem getEnvironment: '#{token}') = '1' ifTrue:[
  Smalltalk addStartBlock:[
  	| p |
    [ 
      "FRESH start"
      Smalltalk addImageStartBlock:[
        "RESTARTING from a snapshot"
        [
          | ok |

          Stdout nextPutLine: 'Restarted from snapshot.'.
          ok := Dialog confirm: 'Does the grid shown in UIPainter''s canvas look OK?'.
          (OperatingSystem getEnvironment: '#{token}') = '1' ifTrue:[
              Smalltalk exit: 121 + (ok ifTrue:[0] ifFalse:[10]).
          ].
        ] fork.
      ].
      p := UIPainter new.
      p open.
      p gridShownHolder value: true.
      p alignToGridHolder value: true.
      p := nil.
      Delay waitForSeconds: 1.
      Smalltalk garbageCollect.  
      ObjectMemory snapShot.
      Smalltalk exit: 123.
    ] fork.
  ].
]
END
end	

ENV[token] = '1'

# Step 1. 
rm_f 'st.img'; rm_f 'st.sav'; rm_f 'st.chg'

# Step 2. 
system "#{stx_cmd} -I --quick"
if $?.exitstatus != 123 then
  raise Exception.new("stx failed to execute (status #{$?.exitstatus})");
end

if not File.exist? 'st.img' then
  raise Exception.new("st.img was not saved")
end

# Step 3.
system "#{stx_cmd} -i st.img"
if $?.exitstatus != 121 then
    puts 
    puts "Start gdb as:"
    puts 
    puts '  C:\mingw64\bin\gdb.exe --args stx-bin.com -i st.img'
    puts 
    raise Exception.new("stx failed to restart from a snapshot (status #{$?.exitstatus})");
end

puts 
puts "PASSED"